@@ -26,8 +26,11 @@ function build_and_install_beta() {
   ./build.sh >/dev/null
   cd ..
 
+  local latest_commit
+  latest_commit=$(git rev-parse --short=8 HEAD);
+
   local beta_version
-  beta_version='(non-stable) beta ['"$(date +'%Y-%m-%d')"']'
+  beta_version='(non-stable) beta after '"$LATEST_BASHUNIT_VERSION"' ['"$(date +'%Y-%m-%d')"'] 🐍 #'"$latest_commit"
 
   sed -i -e 's/BASHUNIT_VERSION=".*"/BASHUNIT_VERSION="'"$beta_version"'"/g' temp_bashunit/bin/bashunit
   cp temp_bashunit/bin/bashunit ./
